@@ -10,9 +10,9 @@ class MapFilter(admin.SimpleListFilter):
     content_names = ('age', 'sex', 'activity', 'protocol', 'location')
 
     def lookups(self, request, model_admin):
-        types = ContentType.objects.get(
+        types = ContentType.objects.filter(
             app_label='checklists', model__in=self.content_names)\
-            .values_list('id', 'name', flat=True)
+            .values_list('id', 'name')
         return tuple([(pk, name.capitalize()) for pk, name in types])
 
     def queryset(self, request, queryset):
@@ -20,5 +20,3 @@ class MapFilter(admin.SimpleListFilter):
             return queryset.filter(content_type_id=self.value())
         else:
             return queryset
-
-
