@@ -16,8 +16,7 @@ from django.template.loader import render_to_string
 from django.utils.safestring import mark_safe
 
 from checklists.models import Map, Filter, Location, Species, \
-    Checklist, Activity, Protocol, Method, Entry, Detail, Age, Sex, Observer, \
-    set_current_user, clear_current_user
+    Checklist, Activity, Protocol, Method, Entry, Detail, Age, Sex, Observer
 
 
 logger = logging.getLogger(__name__)
@@ -393,14 +392,14 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         filtered = []
-        passed = []
+        added = []
+        updated = []
         failed = []
 
         directory = options['dir'] or settings.CHECKLISTS_DOWNLOAD_DIR
         paths = find_files(directory, 'json')
 
         filters = load_filters()
-        set_current_user('load_checklists')
 
         for path in paths:
             try:
@@ -409,10 +408,13 @@ class Command(BaseCommand):
                 if match:
                     filtered.append((path, values, match))
                 else:
-                    messages = []
                     self.denormalize_values(values)
-                    self.add_or_update_checklist(values, messages)
-                    passed.append((path, values, messages))
+                    messages, created = self.add_or_update_checklist(values)
+                    if created:
+                        added.append((path, values, messages))
+                    else:
+                        if messages:
+                            updated.append((path, values, messages))
                     os.remove(path)
             except:
                 kind, value, trace = sys.exc_info()
@@ -421,12 +423,11 @@ class Command(BaseCommand):
 
         report = render_to_string(self.template, {
             'filtered': filtered,
-            'loaded': passed,
+            'added': added,
+            'updated': updated,
             'errors': failed,
         })
 
-        clear_current_user()
-
         if settings.DEBUG:
             filename = os.path.join(directory, 'load_checklists_report.txt')
             with open(filename, 'wb') as fp:
@@ -452,7 +453,8 @@ class Command(BaseCommand):
             entry['language'] = language
             entry['species']['language'] = language
 
-    def add_or_update_checklist(self, values, messages):
+    def add_or_update_checklist(self, values):
+        messages = []
         location = find_map_location(values['location']['name'])
         if not location:
             location, created = self.add_or_update_location(values['location'])
@@ -514,6 +516,8 @@ class Command(BaseCommand):
         for values in values['entries']:
             self.add_or_update_entry(checklist, values, messages)
 
+        return messages, created
+
     def add_or_update_location(self, values):
         params = {
             'name': values['name'],
