@@ -3,6 +3,7 @@ import datetime
 from south.db import db
 from south.v2 import SchemaMigration
 from django.db import models
+from django.utils import timezone
 
 
 class Migration(SchemaMigration):
@@ -15,7 +16,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Checklist.created_on'
         db.add_column('checklists_checklist', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Checklist.modified_by'
@@ -25,7 +26,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Checklist.modified_on'
         db.add_column('checklists_checklist', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Rank.created_by'
@@ -35,7 +36,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Rank.created_on'
         db.add_column('checklists_rank', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Rank.modified_by'
@@ -45,7 +46,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Rank.modified_on'
         db.add_column('checklists_rank', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Sex.created_by'
@@ -55,7 +56,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Sex.created_on'
         db.add_column('checklists_sex', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Sex.modified_by'
@@ -65,7 +66,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Sex.modified_on'
         db.add_column('checklists_sex', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Protocol.created_by'
@@ -75,7 +76,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Protocol.created_on'
         db.add_column('checklists_protocol', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Protocol.modified_by'
@@ -85,7 +86,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Protocol.modified_on'
         db.add_column('checklists_protocol', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'SpeciesGroup.created_by'
@@ -95,7 +96,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'SpeciesGroup.created_on'
         db.add_column('checklists_speciesgroup', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'SpeciesGroup.modified_by'
@@ -105,7 +106,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'SpeciesGroup.modified_on'
         db.add_column('checklists_speciesgroup', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Direction.created_by'
@@ -115,7 +116,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Direction.created_on'
         db.add_column('checklists_direction', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Direction.modified_by'
@@ -125,7 +126,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Direction.modified_on'
         db.add_column('checklists_direction', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Entry.created_by'
@@ -135,7 +136,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Entry.created_on'
         db.add_column('checklists_entry', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Entry.modified_by'
@@ -145,7 +146,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Entry.modified_on'
         db.add_column('checklists_entry', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Plumage.created_by'
@@ -155,7 +156,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Plumage.created_on'
         db.add_column('checklists_plumage', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Plumage.modified_by'
@@ -165,7 +166,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Plumage.modified_on'
         db.add_column('checklists_plumage', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Detail.created_by'
@@ -175,7 +176,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Detail.created_on'
         db.add_column('checklists_detail', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Detail.modified_by'
@@ -185,7 +186,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Detail.modified_on'
         db.add_column('checklists_detail', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'SpeciesStatus.created_by'
@@ -195,7 +196,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'SpeciesStatus.created_on'
         db.add_column(u'checklists_speciesstatus', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'SpeciesStatus.modified_by'
@@ -205,7 +206,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'SpeciesStatus.modified_on'
         db.add_column(u'checklists_speciesstatus', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Species.created_by'
@@ -215,7 +216,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Species.created_on'
         db.add_column('checklists_species', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Species.modified_by'
@@ -225,7 +226,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Species.modified_on'
         db.add_column('checklists_species', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Map.created_by'
@@ -235,7 +236,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Map.created_on'
         db.add_column('checklists_map', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Map.modified_by'
@@ -245,7 +246,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Map.modified_on'
         db.add_column('checklists_map', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Location.created_by'
@@ -255,7 +256,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Location.created_on'
         db.add_column('checklists_location', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Location.modified_by'
@@ -265,7 +266,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Location.modified_on'
         db.add_column('checklists_location', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'EntryTag.created_by'
@@ -275,7 +276,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'EntryTag.created_on'
         db.add_column(u'checklists_entrytag', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'EntryTag.modified_by'
@@ -285,7 +286,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'EntryTag.modified_on'
         db.add_column(u'checklists_entrytag', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Method.created_by'
@@ -295,7 +296,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Method.created_on'
         db.add_column('checklists_method', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Method.modified_by'
@@ -305,7 +306,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Method.modified_on'
         db.add_column('checklists_method', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Filter.created_by'
@@ -315,7 +316,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Filter.created_on'
         db.add_column('checklists_filter', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Filter.modified_by'
@@ -325,7 +326,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Filter.modified_on'
         db.add_column('checklists_filter', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Age.created_by'
@@ -335,7 +336,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Age.created_on'
         db.add_column('checklists_age', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Age.modified_by'
@@ -345,7 +346,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Age.modified_on'
         db.add_column('checklists_age', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Observer.created_by'
@@ -355,7 +356,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Observer.created_on'
         db.add_column('checklists_observer', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Observer.modified_by'
@@ -365,7 +366,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Observer.modified_on'
         db.add_column('checklists_observer', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Activity.created_by'
@@ -375,7 +376,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Activity.created_on'
         db.add_column('checklists_activity', 'created_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=timezone.now, blank=True),
                       keep_default=False)
 
         # Adding field 'Activity.modified_by'
@@ -385,7 +386,7 @@ class Migration(SchemaMigration):
 
         # Adding field 'Activity.modified_on'
         db.add_column('checklists_activity', 'modified_on',
-                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=datetime.datetime.min, blank=True),
+                      self.gf('django.db.models.fields.DateTimeField')(auto_now=True, default=timezone.now, blank=True),
                       keep_default=False)
 
 
