@@ -20,7 +20,6 @@ records were updated and the database will remain consistent.
 
 from datetime import date
 
-from django.contrib.auth.models import User
 from django.contrib.contenttypes.generic import GenericForeignKey
 from django.core.validators import MinValueValidator
 from django.db.models import Model, BooleanField, IntegerField, \
@@ -34,23 +33,10 @@ from django.contrib.contenttypes.models import ContentType
 
 from transmeta import TransMeta
 
-from threading import local
+from utils import get_user_model
 
 
-_thread_locals = local()
-
-
-def set_current_user(user):
-    _thread_locals.user = user
-
-
-def get_current_user():
-    return getattr(_thread_locals, 'user', '')
-
-
-def clear_current_user():
-    if hasattr(_thread_locals, 'user'):
-        del _thread_locals.user
+User = get_user_model()
 
 
 class ChecklistsModel(Model):
@@ -59,20 +45,11 @@ class ChecklistsModel(Model):
     class Meta:
         abstract = True
 
-    created_by = CharField(max_length=50, blank=True)
-    created_on = DateTimeField(auto_now_add=True)
-    modified_by = CharField(max_length=50, blank=True)
-    modified_on = DateTimeField(auto_now=True)
-
     def save(self, force_insert=False, force_update=False, **kwargs):
         """Validate a model object on save."""
         if not (force_insert or force_update):
             self.full_clean()
 
-        self.modified_by = get_current_user()
-        if not self.pk:
-            self.created_by = self.modified_by
-
         super(ChecklistsModel, self)\
             .save(force_insert, force_update, **kwargs)
 
@@ -522,8 +499,7 @@ class Observer(ChecklistsModel):
 
     """The names of observers submitting records.
 
-    An Observer is not necessarily a User so the relationship to auth.User
-    is optional.
+    An Observer is not necessarily a User so the relationship is optional.
     """
 
     user = OneToOneField(User, null=True, blank=True)
