@@ -11,7 +11,5 @@ def run(*args):
     call_command('runscript', 'load_protocols')
     call_command('runscript', 'load_ranks')
     call_command('runscript', 'load_sexes')
-    call_command('runscript', 'load_species_groups', script_args=args)
-    call_command('runscript', 'load_species', script_args=args)
-
+    call_command('runscript', 'load_taxonomy')
     call_command('runscript', 'load_map')
