@@ -1,5 +1,4 @@
-from checklists.models import Map, Activity, Age, Protocol, Sex, \
-    set_current_user, clear_current_user
+from checklists.models import Map, Activity, Age, Protocol, Sex
 
 activities = (
     ('Birding', 'birding'),
@@ -26,8 +25,6 @@ sexes = (
 
 
 def run():
-    set_current_user('load_map')
-
     Map.objects.all().delete()
 
     for name, slug in activities:
@@ -45,5 +42,3 @@ def run():
     for name, slug in sexes:
         Map.objects.create(
             name=name, content_object=Sex.objects.get(slug=slug))
-
-    clear_current_user()
