@@ -533,7 +533,7 @@ class StatusReportTestCase(SimpleTestCase):
 
     def test_status_report_loaded_section(self):
         contents = mail.outbox[0].body
-        self.assertTrue("Checklists loaded" in contents)
+        self.assertTrue("Checklists added" in contents)
 
     def test_status_report_contains_checklist(self):
         contents = mail.outbox[0].body
